@@ -27,7 +27,7 @@ if __name__ == '__main__':
     from optparse import OptionParser
 
     p = OptionParser()
-    p.set_usage('corr_10gbe_deconfig.py CONFIG_FILE')
+    p.set_usage('%prog CONFIG_FILE')
     p.set_description(__doc__)
 
     opts, args = p.parse_args(sys.argv[1:])
@@ -36,12 +36,10 @@ if __name__ == '__main__':
         print 'Please specify a configuration file! \nExiting.'
         exit()
 
-lh=corr.log_handlers.DebugLogHandler()
-
 try:
     print 'Connecting...',
     c=corr.corr_functions.Correlator(args[0],lh)
-    for logger in c.xloggers: logger.setLevel(10)
+    for logger in c.loggers: logger.setLevel(10)
     print 'done.'
 
     print('\nKilling all 10GbE tgtap drivers...'),
