@@ -109,7 +109,7 @@ try:
     subplots = []
     numberOfPolarisations = len(polList)
     for p, pol in enumerate(polList):
-        subPlot = matplotlib.pyplot.subplot(numberOfPolarisations, 1, p + 1)
+        subPlot = fig.add_subplot(numberOfPolarisations, 1, p + 1)
         subplots.append(subPlot)
 
     # callback function to draw the data for all the required polarisations
@@ -128,6 +128,7 @@ try:
             for p2, pol2 in enumerate(polList):
                 matplotlib.pyplot.subplot(len(polList), 1, p2 + 1)
                 matplotlib.pyplot.ylim(ymax = maxY)
+        fig.canvas.draw()
         fig.canvas.manager.window.after(100, drawDataCallback, comparePlots)
 
     # start the process
