@@ -50,7 +50,7 @@ if __name__ == '__main__':
     p.set_usage('%prog [options] CONFIG_FILE')
     p.set_description(__doc__)
     p.add_option('-i', '--init_eq', dest='init_eq', type='int', default=-1,
-        help='''Initialise all F engine equaliser channels to specified value.''')
+        help='''Initialise all F engine equaliser channels to specified value. Default: use config file''')
     #p.add_option('-p', '--eq_poly', dest='eq_poly', action='store_true', default=False,
     #    help='''Initialise all F engine equaliser channels to the equalization polynomials specified in the config file.''')
 
