@@ -22,7 +22,7 @@ if __name__ == '__main__':
     from optparse import OptionParser
 
     p = OptionParser()
-    p.set_usage('corr_rst_gbe.py CONFIG_FILE')
+    p.set_usage('%prog CONFIG_FILE')
     p.set_description(__doc__)
 
     opts, args = p.parse_args(sys.argv[1:])
@@ -36,16 +36,23 @@ lh=corr.log_handlers.DebugLogHandler()
 try:
     print 'Connecting...',
     c=corr.corr_functions.Correlator(args[0],lh)
-    for logger in c.xloggers: logger.setLevel(10)
+    for logger in c.loggers: logger.setLevel(10)
     print 'done.'
 
     print('\nResetting GBE cores...'),
     sys.stdout.flush()
 
-    c.xeng_ctrl_set_all(gbe_disable=True) #DO NOT RESET THE 10GBE CORES SYNCHRONOUSLY... Packets will be routed strangely!
-    c.xeng_ctrl_set_all(gbe_disable=True, gbe_rst=True)
-    c.xeng_ctrl_set_all(gbe_disable=True, gbe_rst=False)
-    c.xeng_ctrl_set_all(gbe_disable=False, gbe_rst=False)
+    #DO NOT RESET THE 10GBE CORES SYNCHRONOUSLY!
+    if c.config['feng_out_type']=='10gbe':
+        c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
+        c.feng_ctrl_set_all(gbe_enable=False,gbe_rst=True)
+        c.feng_ctrl_set_all(gbe_enable=False,gbe_rst=False)
+        c.feng_ctrl_set_all(gbe_enable=True,gbe_rst=False)
+
+    c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=False) 
+    c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=True)
+    c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
+    c.xeng_ctrl_set_all(gbe_enable=True, gbe_rst=False)
 
     print 'done.'
 
