@@ -3,6 +3,7 @@
 Reads the error counters on the correlator Xengines and reports such things as accumulated XAUI and packet errors.
 \n\n
 Revisions:
+2010-11-25  JRM Bugfix to also lookup gbe_tx_cnt if hardware outputs 10Gbe
 2010-10-25  PVP Use ncurses via class scroll in scroll.py to allow scrolling around on-screen data
 2010-07-22  JRM Ported for corr-0.5.5
 2009-12-01  JRM Layout changes, check for loopback sync
@@ -71,8 +72,6 @@ try:
                 loopback_ok=c.check_loopback_mcnt() 
                 xaui_errors=[c.xread_uint_all('xaui_err%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
                 xaui_rx_cnt=[c.xread_uint_all('xaui_cnt%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
-                gbe_tx_cnt =[c.xread_uint_all('gbe_tx_cnt%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
-                gbe_tx_err =[c.xread_uint_all('gbe_tx_err_cnt%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
                 loop_cnt   = [c.xread_uint_all('loop_cnt%i'%x) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
                 loop_err_cnt = [c.xread_uint_all('loop_err_cnt%i'%x) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
                 mcnts      = [c.xread_uint_all('loopback_mux%i_mcnt'%(x)) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
@@ -81,6 +80,10 @@ try:
                     loopmcnt.append([mv[x]/(2**16) for x,f in enumerate(c.xfpgas)])
                     gbemcnt.append([mv[x]&((2**16)-1) for x,f in enumerate(c.xfpgas)])
 
+            if c.config['feng_out_type']=='xaui' or c.config['out_type']=='10gbe':
+                gbe_tx_cnt =[c.xread_uint_all('gbe_tx_cnt%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
+                gbe_tx_err =[c.xread_uint_all('gbe_tx_err_cnt%i'%(x)) for x in range(n_xaui_ports_per_fpga)]
+
             rx_cnt     = [c.xread_uint_all('rx_cnt%i'%(x)) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
             gbe_rx_cnt = [c.xread_uint_all('gbe_rx_cnt%i'%x) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
             gbe_rx_err_cnt = [c.xread_uint_all('gbe_rx_err_cnt%i'%x) for x in range(min(n_xaui_ports_per_fpga,n_xeng_per_fpga))]
