@@ -6,6 +6,7 @@ UNDER CONSTRUCTION
 
 Author: Jason Manley\n
 Revisions:\n
+2010-11-26: JRM Added longterm ppc count check in feng clock check.
 2010-11-22: JRM corr-0.6.0 now with support for fengines with 10gbe cores instead of xaui links.
                 Mods to fr_delay calcs for fine delay.
                 spead, pcnt and mcnt from time functions now account for wrapping counters.
@@ -44,12 +45,6 @@ class Correlator:
         self.xloggers=[logging.getLogger(s) for s in self.xsrvs]
         self.syslogger=logging.getLogger('corrsys')
         self.loggers=self.floggers + self.xloggers
-        for logger in (self.loggers): 
-            logger.addHandler(self.log_handler)
-            logger.setLevel(log_level)
-        self.syslogger.addHandler(self.log_handler)
-        self.syslogger.setLevel(log_level)
-
 
         self.xfpgas=[corr.katcp_wrapper.FpgaClient(server,self.config['katcp_port'],
                        timeout=10,logger=self.xloggers[s]) for s,server in enumerate(self.xsrvs)]
@@ -57,6 +52,12 @@ class Correlator:
                        timeout=10,logger=self.floggers[s]) for s,server in enumerate(self.fsrvs)]
         self.allfpgas = self.ffpgas + self.xfpgas
 
+        for logger in (self.loggers): 
+            logger.addHandler(self.log_handler)
+            logger.setLevel(log_level)
+        self.syslogger.addHandler(self.log_handler)
+        self.syslogger.setLevel(log_level)
+
         time.sleep(1)
         if not self.check_katcp_connections():
             raise RuntimeError("Connection to FPGA boards failed.")
@@ -165,6 +166,7 @@ class Correlator:
             \n\t tvg_pkt_sel
             \n\t tvg_ct_sel
             \n\t tvg_en
+            \n\t adc_protect_disable 
             \n\t flasher_en
             \n\t gbe_enable
             \n\t gbe_rst
@@ -179,6 +181,7 @@ class Correlator:
             'tvg_pkt_sel':  18,
             'tvg_ct_sel':   17,
             'tvg_en':       16,
+            'adc_protect_disable':   13,
             'flasher_en':   12,
             'gbe_enable':   9,
             'gbe_rst':      8,
@@ -220,6 +223,7 @@ class Correlator:
                 'clr_status':bool(value&(1<<3)),
                 'gbe_rst': bool(value&(1<<8)),
                 'gbe_enable': bool(value&(1<<9)),
+                'adc_protect_disable':bool(value&(1<<13)),
                 'flasher_en':bool(value&(1<<12)),
                 'tvg_en':bool(value&(1<<16)),
                 'tvg_ct_sel':bool(value&(1<<17)),
@@ -324,8 +328,11 @@ class Correlator:
                 ffpga_n,xfpga_n,fxaui_n,xxaui_n,feng_input = self.get_ant_location(ant,pol)
                 value = self.ffpgas[ffpga_n].read_uint('fstatus%i'%feng_input)
                 #for xaui_n in range(self.config['n_xaui_per_ffpga
-                rv[(ant,pol)]={'xaui_lnkdn':bool(value&(1<<17)),
+                rv[(ant,pol)]={
+                                'sync_val':(value&((2**32)-(2**28)))>>28,
+                                'xaui_lnkdn':bool(value&(1<<17)),
                                 'xaui_over':bool(value&(1<<16)),
+                                'adc_bad':bool(value&(1<<4)),
                                 'ct_error':bool(value&(1<<3)),
                                 'adc_overrange':bool(value&(1<<2)),
                                 'fft_overrange':bool(value&(1<<1)),
@@ -444,31 +451,36 @@ class Correlator:
             if stat[xn]['gbe_out_enable'] != True or stat[xn]['gbe_out_rst']!=False: rv=False
         return rv
 
-    def check_feng_clks(self):
+    def check_feng_clks(self, quick_test=False):
         """ Checks all Fengine FPGAs' clk_frequency registers to confirm correct PPS operation. Requires that the system be sync'd."""
         #tested ok corr-0.5.0 2010-07-19
         import stats
         rv=True
-       
-        #estimate actual clk freq 
-        clk_freq=self.feng_clks_get()
-        clk_mhz=[round(cf) for cf in clk_freq] #round to nearest MHz
         expect_rate = round(self.config['feng_clk']/1000000) #expected clock rate in MHz.
-        for fbrd,fsrv in enumerate(self.fsrvs):
-            if clk_freq[fbrd] <= 100: 
-                self.floggers[fbrd].error("No clock detected!")
-                rv=False
 
-            if (clk_mhz[fbrd] > (expect_rate+1)) or (clk_mhz[fbrd] < (expect_rate -1)) or (clk_mhz[fbrd]==0):
-               self.floggers[fbrd].error("Clock freq is %i MHz, where expected rate is %i MHz."%(clk_mhz[fbrd], expect_rate))
-               rv=False
+        #estimate actual clk freq 
+        if quick_test==False:
+            clk_freq=self.feng_clks_get()
+            clk_mhz=[round(cf) for cf in clk_freq] #round to nearest MHz
+            for fbrd,fsrv in enumerate(self.fsrvs):
+                if clk_freq[fbrd] <= 100: 
+                    self.floggers[fbrd].error("No clock detected!")
+                    rv=False
 
-        if rv==False: 
-            self.syslogger.error("Some Fengine clocks are dead. We can't continue.")
-            return False
+                if (clk_mhz[fbrd] > (expect_rate+1)) or (clk_mhz[fbrd] < (expect_rate -1)) or (clk_mhz[fbrd]==0):
+                   self.floggers[fbrd].error("Estimated clock freq is %i MHz, where expected rate is %i MHz."%(clk_mhz[fbrd], expect_rate))
+                   rv=False
+
+
+            if rv==False: 
+                self.syslogger.error("Some Fengine clocks are dead. We can't continue.")
+                return False
+            else: 
+                self.syslogger.info("Fengine clocks are approximately correct at %i MHz."%expect_rate)
 
         #check long-term integrity
         uptime=[ut[1] for ut in self.feng_uptime()]
+        exp_uptime = numpy.floor(time.time() - self.config['sync_time'])
         mode = stats.mode(uptime)
         modalmean=stats.mean(mode[1])
         for fbrd,fsrv in enumerate(self.fsrvs):
@@ -476,26 +488,36 @@ class Correlator:
                 rv=False
                 self.floggers[fbrd].error("No PPS detected! PPS count is zero.")
 
-            if (uptime[fbrd] > (modalmean+1)) or (uptime[fbrd] < (modalmean -1)) or (uptime[fbrd]==0):
+            elif (uptime[fbrd] > (modalmean+1)) or (uptime[fbrd] < (modalmean -1)) or (uptime[fbrd]==0):
                 rv=False
                 self.floggers[fbrd].error("PPS count is %i pulses, where modal mean is %i pulses. This board has a bad 1PPS input."%(uptime[fbrd], modalmean))
 
+            elif uptime[fbrd] != exp_uptime: 
+                rv=False
+                self.floggers[fbrd].error("Expected uptime is %i seconds, but we've counted %i PPS pulses."%(exp_uptime,uptime[fbrd]))
+            else:
+                self.floggers[fbrd].info("Uptime is %i seconds, as expected."%(uptime[fbrd]))
+
         #check the PPS against sampling clock.
         all_values = self.fread_uint_all('clk_frequency')
         mode = stats.mode(all_values)
         modalmean=stats.mean(mode[1])
         modalfreq=numpy.round((expect_rate*1000000.)/modalmean,3)
         if (modalfreq != 1):
-            self.syslogger.warn("PPS period is approx %3.2f Hz, not 1Hz."%modalfreq)
+            self.syslogger.error("PPS period is approx %3.2f Hz, not 1Hz."%modalfreq)
             rv=False
+        else:
+            self.syslogger.info("Assuming a clock of %iMHz and that the PPS and clock are correct on most boards, PPS period is %3.2fHz and clock rate is %6.3fMHz."%(expect_rate,modalfreq,modalmean/1000000.))
 
         for fbrd,fsrv in enumerate(self.fsrvs):
             if all_values[fbrd] == 0: 
                 self.floggers[fbrd].error("No PPS or no clock... clk_freq register is zero!")
                 rv=False
             if (all_values[fbrd] > (modalmean+2)) or (all_values[fbrd] < (modalmean -2)) or (all_values[fbrd]==0):
-                self.floggers[fbrd].error("Clocks between PPS pulses is %i, where modal mean is %i."%(all_values[fbrd], modalmean))
+                self.floggers[fbrd].error("Clocks between PPS pulses is %i, where modal mean is %i. This board has a bad sampling clock or PPS input."%(all_values[fbrd], modalmean))
                 rv=False
+            else:
+                self.floggers[fbrd].info("Clocks between PPS pulses is %i as expected."%(all_values[fbrd]))
 
         return rv
 
